<div dir="rtl">

# پکیج فاکتور پلتفرم پاد

این پکیج شامل سرویس های زیر است
* صدور فاکتور
* کاهش فاکتور
* لیست فاکتورها
* روش های پرداخت فاکتور
* و ...

# نصب

برای نصب از طریق `pip` کافیه تا دستور زیر را اجرا کنید
```
pip install pod-billing
```


# نمونه کد

نمونه کد ها و مثال هایی از تمام متدهای این پکیج را می توانید 
[اینجا](examples)
پیدا کنید.

</div>